@@ -28,7 +28,7 @@
 #include <syslog.h>
 #include <unistd.h>
 #include <vpn.h>
-#include <c-ctype.h>
+#include <ctype.h>
 #include "gssapi.h"
 #include "auth/common.h"
 #include "auth-unix.h"
@@ -137,7 +137,6 @@ static void gssapi_vhost_init(void **_vctx, void *pool, void *additional)
 	}
 
 	*_vctx = vctx;
-	return;
 }
 
 static void gssapi_vhost_deinit(void *_vctx)
