@@ -23,12 +23,9 @@
 #include <stdlib.h>
 #include <string.h>
 #include <syslog.h>
-#ifndef _XOPEN_SOURCE
-# define _XOPEN_SOURCE
-#endif
 #include <unistd.h>
 #include <vpn.h>
-#include <c-ctype.h>
+#include <ctype.h>
 #include "plain.h"
 #include "common-config.h"
 #include "auth/common.h"
@@ -76,7 +73,6 @@ static void plain_vhost_init(void **vctx, void *pool, void *additional)
 #ifdef HAVE_LIBOATH
 	oath_init();
 #endif
-	return;
 }
 
 /* Breaks a list of "xxx", "yyy", to a character array, of
@@ -106,7 +102,7 @@ break_group_list(void *pool, char *text,
 
 			/* remove any trailing space */
 			p2 = p-1;
-			while (c_isspace(*p2)) {
+			while (isspace(*p2)) {
 				*p2 = 0;
 				p2--;
 			}
@@ -114,7 +110,7 @@ break_group_list(void *pool, char *text,
 			p++;	/* move to next entry and skip white
 				 * space.
 				 */
-			while (c_isspace(*p))
+			while (isspace(*p))
 				p++;
 
 			if (len == 1) {
@@ -124,7 +120,7 @@ break_group_list(void *pool, char *text,
 		} else {
 			p2 = strrchr(broken_text[(*elements)-1], ' ');
 			if (p2 != NULL) {
-				while (c_isspace(*p2)) {
+				while (isspace(*p2)) {
 					*p2 = 0;
 					p2--;
 				}
@@ -483,7 +479,6 @@ static void plain_group_list(void *pool, void *additional, char ***groupname, un
 	htable_clear(&hash);
 	safe_memset(line, 0, sizeof(line));
 	fclose(fp);
-	return;
 }
 
 const struct auth_mod_st plain_auth_funcs = {
