@@ -29,8 +29,7 @@
 #include <limits.h>
 #include <common.h>
 #include <ip-util.h>
-#include <c-strcase.h>
-#include <c-ctype.h>
+#include <ctype.h>
 #include <auth/pam.h>
 #include <acct/pam.h>
 #include <auth/radius.h>
@@ -103,7 +102,7 @@ static void check_cfg(vhost_cfg_st *vhost, vhost_cfg_st *defvhost, unsigned sile
 
 #define PREAD_STRING(pool, varname) { \
 	unsigned len = strlen(value); \
-	while(len > 0 && c_isspace(value[len-1])) \
+	while (len > 0 && isspace(value[len-1])) \
 		len--; \
 	varname = talloc_strndup(pool, value, len); \
 	}
@@ -115,8 +114,8 @@ static void check_cfg(vhost_cfg_st *vhost, vhost_cfg_st *defvhost, unsigned sile
 	strlcpy(varname, value, sizeof(varname)); \
 	}
 
-#define READ_TF(varname) {\
-	if (c_strcasecmp(value, "true") == 0 || c_strcasecmp(value, "yes") == 0) \
+#define READ_TF(varname) { \
+	if (strcasecmp(value, "true") == 0 || strcasecmp(value, "yes") == 0) \
 		varname = 1; \
 	else \
 		varname = 0; \
@@ -126,14 +125,14 @@ static void check_cfg(vhost_cfg_st *vhost, vhost_cfg_st *defvhost, unsigned sile
 	varname = strtol(value, NULL, 10); \
 	}
 
-#define READ_PRIO_TOS(varname) \
+#define READ_PRIO_TOS(varname) { \
 	if (strncmp(value, "0x", 2) == 0) { \
 		varname = strtol(value, NULL, 16); \
 		varname = TOS_PACK(varname); \
 	} else { \
 		varname = strtol(value, NULL, 10); \
 		varname++; \
-	}
+	}}
 
 struct snapshot_t * config_snapshot = NULL;
 
@@ -228,7 +227,7 @@ static void figure_auth_funcs(void *pool, const char *vhostname,
 		for (j=0;j<auth_size;j++) {
 			found = 0;
 			for (i=0;i<ARRAY_SIZE(avail_auth_types);i++) {
-				if (c_strncasecmp(auth[j], avail_auth_types[i].name, avail_auth_types[i].name_size) == 0) {
+				if (strncasecmp(auth[j], avail_auth_types[i].name, avail_auth_types[i].name_size) == 0) {
 					if (avail_auth_types[i].get_brackets_string)
 						config->auth[0].additional = avail_auth_types[i].get_brackets_string(pool, config, auth[j]+avail_auth_types[i].name_size);
 
@@ -268,7 +267,7 @@ static void figure_auth_funcs(void *pool, const char *vhostname,
 		for (j=0;j<auth_size;j++) {
 			found = 0;
 			for (i=0;i<ARRAY_SIZE(avail_auth_types);i++) {
-				if (c_strncasecmp(auth[j], avail_auth_types[i].name, avail_auth_types[i].name_size) == 0) {
+				if (strncasecmp(auth[j], avail_auth_types[i].name, avail_auth_types[i].name_size) == 0) {
 					if (avail_auth_types[i].get_brackets_string)
 						config->auth[x].additional = avail_auth_types[i].get_brackets_string(pool, config, auth[j]+avail_auth_types[i].name_size);
 
@@ -327,7 +326,7 @@ static void figure_acct_funcs(void *pool, const char *vhostname, struct perm_cfg
 
 	/* Set the accounting method */
 	for (i=0;i<ARRAY_SIZE(avail_acct_types);i++) {
-		if (c_strncasecmp(acct, avail_acct_types[i].name, avail_acct_types[i].name_size) == 0) {
+		if (strncasecmp(acct, avail_acct_types[i].name, avail_acct_types[i].name_size) == 0) {
 			if (avail_acct_types[i].mod == NULL)
 				continue;
 
@@ -429,10 +428,10 @@ char *sanitize_config_value(void *pool, const char *value)
 	ssize_t len = strlen(value);
 	unsigned i = 0;
 
-	while(c_isspace(value[len-1]) || value[len-1] == '"')
+	while (isspace(value[len-1]) || value[len-1] == '"')
 		len--;
 
-	while(c_isspace(value[i]) || value[i] == '"') {
+	while (isspace(value[i]) || value[i] == '"') {
 		i++;
 		len--;
 	}
@@ -440,7 +439,7 @@ char *sanitize_config_value(void *pool, const char *value)
 	if (len < 0)
 		return NULL;
 
-	return talloc_strndup(pool, &value[i], len); \
+	return talloc_strndup(pool, &value[i], len);
 
 }
 
@@ -489,8 +488,6 @@ static void append_iroutes_from_file(struct cfg_st *config, const char *file)
 		if (ip_route_sanity_check(config->known_iroutes, &config->known_iroutes[j]) != 0)
 			exit(EXIT_FAILURE);
 	}
-
-	return;
 }
 
 static void load_iroutes(struct cfg_st *config)
@@ -514,7 +511,7 @@ static void load_iroutes(struct cfg_st *config)
 				}
 				append_iroutes_from_file(config, path);
 			}
-		} while(r != NULL);
+		} while (r != NULL);
 		closedir(dir);
 	}
 }
@@ -671,12 +668,12 @@ char *sanitize_name(void *pool, const char *p)
 {
 	size_t len;
 	/* cleanup spaces before and after */
-	while (c_isspace(*p))
+	while (isspace(*p))
 		p++;
 
 	len = strlen(p);
 	if (len > 0) {
-		while (c_isspace(p[len-1]))
+		while (isspace(p[len-1]))
 			len--;
 	}
 
@@ -728,7 +725,7 @@ static int cfg_ini_handler(void *_ctx, const char *section, const char *name, co
 			}
 		}
 
-		if (c_strcasecmp(section+6, vname) != 0) {
+		if (strcasecmp(section+6, vname) != 0) {
 			fprintf(stderr, NOTESTR"virtual host name '%s' was canonicalized to '%s'\n",
 				section+6, vname);
 		}
@@ -917,6 +914,8 @@ static int cfg_ini_handler(void *_ctx, const char *section, const char *name, co
 			fprintf(stderr, NOTESTR"'always-require-cert' was replaced by 'cisco-client-compat'\n");
 			config->cisco_client_compat = 1;
 		}
+	} else if (strcmp(name, "cisco-svc-client-compat") == 0) {
+		READ_TF(config->cisco_svc_client_compat);
 	} else if (strcmp(name, "dtls-psk") == 0) {
 		if (!WARN_ON_VHOST(vhost->name, "dtls-psk", dtls_psk))
 			READ_TF(config->dtls_psk);
@@ -1124,6 +1123,12 @@ static int cfg_ini_handler(void *_ctx, const char *section, const char *name, co
 		READ_STRING(config->default_user_conf);
 	} else if (strcmp(name, "default-group-config") == 0) {
 		READ_STRING(config->default_group_conf);
+	} else if (strcmp(name, "camouflage") == 0) {
+		READ_TF(config->camouflage);
+	} else if (strcmp(name, "camouflage_secret") == 0) {
+		READ_STRING(config->camouflage_secret);
+	} else if (strcmp(name, "camouflage_realm") == 0) {
+		READ_STRING(config->camouflage_realm);
 	} else {
 		if (reload == 0)
 			fprintf(stderr, WARNSTR"skipping unknown option '%s'\n", name);
@@ -1420,7 +1425,7 @@ static void check_cfg(vhost_cfg_st *vhost, vhost_cfg_st *defvhost, unsigned sile
 	}
 
 	if (config->cert_req != 0 && config->cert_user_oid != NULL) {
-		if (!c_isdigit(config->cert_user_oid[0]) && strcmp(config->cert_user_oid, "SAN(rfc822name)") != 0) {
+		if (!isdigit(config->cert_user_oid[0]) && strcmp(config->cert_user_oid, "SAN(rfc822name)") != 0) {
 			fprintf(stderr, ERRSTR"%sthe option 'cert-user-oid' has a unsupported value\n", PREFIX_VHOST(vhost));
 			exit(EXIT_FAILURE);
 		}
@@ -1451,6 +1456,19 @@ static void check_cfg(vhost_cfg_st *vhost, vhost_cfg_st *defvhost, unsigned sile
 	}
 #endif
 
+	if (config->cisco_svc_client_compat) {
+		if (!config->dtls_legacy && !silent) {
+			fprintf(stderr, NOTESTR"%sthe cisco-svc-client-compat option implies dtls-legacy = true; enabling\n", PREFIX_VHOST(vhost));
+		}
+		config->dtls_legacy = 1;
+
+		/* The client will only connect to port 443 */
+		if (vhost->perm_config.udp_port != 0 && vhost->perm_config.udp_port != 443) {
+			fprintf(stderr, ERRSTR"%s cisco-svc-client-compat option requires udp-port = 443\n", PREFIX_VHOST(vhost));
+			exit(EXIT_FAILURE);
+		}
+	}
+
 	if (config->priorities == NULL) {
 		char *tmp = "";
 		/* on vhosts assign the main host priorities. We furthermore disable TLS1.3 on Cisco clients
@@ -1609,34 +1627,34 @@ int cmd_parser (void *pool, int argc, char **argv, struct list_head *head, bool
 		if (c == -1)
 			break;
 
-		switch(c) {
-			case 'f':
-				vhost->perm_config.foreground = 1;
-				break;
-			case 'p':
-				strlcpy(pid_file, optarg, sizeof(pid_file));
-				break;
-			case 'c':
-				strlcpy(cfg_file, optarg, sizeof(cfg_file));
-				break;
-			case 'd':
-				vhost->perm_config.debug = atoi(optarg);
-				break;
-			case 't':
-				test_only = 1;
-				break;
-			case OPT_NO_CHDIR:
-				vhost->perm_config.no_chdir = 1;
-				break;
-			case 'h':
-				usage();
-				exit(EXIT_SUCCESS);
-			case 'v':
-				print_version();
-				exit(EXIT_SUCCESS);
-			case 'x':
-				vhost->perm_config.pr_dumpable = 1;
-				break;
+		switch (c) {
+		case 'f':
+			vhost->perm_config.foreground = 1;
+			break;
+		case 'p':
+			strlcpy(pid_file, optarg, sizeof(pid_file));
+			break;
+		case 'c':
+			strlcpy(cfg_file, optarg, sizeof(cfg_file));
+			break;
+		case 'd':
+			vhost->perm_config.debug = atoi(optarg);
+			break;
+		case 't':
+			test_only = 1;
+			break;
+		case OPT_NO_CHDIR:
+			vhost->perm_config.no_chdir = 1;
+			break;
+		case 'h':
+			usage();
+			exit(EXIT_SUCCESS);
+		case 'v':
+			print_version();
+			exit(EXIT_SUCCESS);
+		case 'x':
+			vhost->perm_config.pr_dumpable = 1;
+			break;
 		}
 	}
 
@@ -1688,8 +1706,6 @@ static void archive_cfg(struct list_head *head)
 			list_add(&vhost->perm_config.attic, &e->list);
 		}
 	}
-
-	return;
 }
 
 static void clear_cfg(struct list_head *head)
@@ -1701,8 +1717,6 @@ static void clear_cfg(struct list_head *head)
 		talloc_free(cpos->perm_config.config);
 		cpos->perm_config.config = NULL;
 	}
-
-	return;
 }
 
 void clear_vhosts(struct list_head *head)
@@ -1715,8 +1729,6 @@ void clear_vhosts(struct list_head *head)
 		talloc_free(vhost->perm_config.config);
 		vhost->perm_config.config = NULL;
 	}
-
-	return;
 }
 
 static void append(const char *option)
@@ -1795,8 +1807,6 @@ void reload_cfg_file(void *pool, struct list_head *configs, unsigned sec_mod)
 
 	/* parse the config again */
 	parse_cfg_file(pool, cfg_file, configs, flags);
-
-	return;
 }
 
 void write_pid_file(void)
