@@ -16,8 +16,8 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef ISOLATE_H
-# define ISOLATE_H
+#ifndef OC_ISOLATE_H
+# define OC_ISOLATE_H
 
 
 void init_fd_limits_default(struct main_server_st * s);
@@ -30,4 +30,4 @@ void set_self_oom_score_adj(struct main_server_st * s);
 
 void drop_privileges(struct main_server_st * s);
 
-#endif
\ No newline at end of file
+#endif
