@@ -27,9 +27,6 @@
 #include <errno.h>
 #include <stdlib.h>
 #include <stdarg.h>
-#ifndef _GNU_SOURCE
-# define _GNU_SOURCE /* for vasprintf() */
-#endif
 #include <stdio.h>
 #include <string.h>
 #include <sys/types.h>
@@ -49,11 +46,11 @@
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <netinet/tcp.h>
-#include <c-ctype.h>
+#include <ctype.h>
 
 #ifndef UNDER_TEST
 static void tls_reload_ocsp(main_server_st* s, struct vhost_cfg_st *vhost);
-#endif
+#endif /* UNDER_TEST */
 
 void cstp_cork(worker_st *ws)
 {
@@ -99,7 +96,7 @@ ssize_t cstp_send(worker_st *ws, const void *data,
 	const uint8_t* p = data;
 
 	if (ws->session != NULL) {
-		while(left > 0) {
+		while (left > 0) {
 			ret = gnutls_record_send(ws->session, p, data_size);
 			if (ret < 0) {
 				if (ret != GNUTLS_E_AGAIN && ret != GNUTLS_E_INTERRUPTED) {
@@ -160,7 +157,7 @@ int recv_remaining(int fd, uint8_t *p, int left)
 	unsigned total = 0;
 	int ret;
 
-	while(left > 0) {
+	while (left > 0) {
 		ret = recv(fd, p, left, 0);
 		if (ret == -1 && counter > 0 && (errno == EINTR || errno == EAGAIN)) {
 			counter--;
@@ -269,7 +266,7 @@ ssize_t cstp_recv(worker_st *ws, void *data, size_t data_size)
 				counter--;
 				ms_sleep(20);
 			}
-		} while(ret == -1 && (errno == EINTR || errno == EAGAIN) && counter > 0);
+		} while (ret == -1 && (errno == EINTR || errno == EAGAIN) && counter > 0);
 	}
 
 	return ret;
@@ -371,7 +368,7 @@ ssize_t dtls_send(struct dtls_st *dtls, const void *data,
 	int left = data_size;
 	const uint8_t* p = data;
 
-	while(left > 0) {
+	while (left > 0) {
 		ret = gnutls_record_send(dtls->dtls_session, p, data_size);
 		if (ret < 0) {
 			if (ret != GNUTLS_E_AGAIN && ret != GNUTLS_E_INTERRUPTED) {
@@ -420,7 +417,7 @@ void tls_cache_deinit(tls_sess_db_st* db)
 	struct htable_iter iter;
 
 	cache = htable_first(db->ht, &iter);
-	while(cache != NULL) {
+	while (cache != NULL) {
 		if (cache->session_data_size > 0) {
 			safe_memset(cache->session_data, 0, cache->session_data_size);
 			cache->session_data_size = 0;
@@ -433,14 +430,14 @@ void tls_cache_deinit(tls_sess_db_st* db)
         htable_clear(db->ht);
 	db->entries = 0;
 	talloc_free(db->ht);
-
-        return;
 }
 
+#ifndef UNDER_TEST
 static void tls_log_func(int level, const char *str)
 {
 	syslog(LOG_DEBUG, "TLS[<%d>]: %s", level, str);
 }
+#endif /* UNDER_TEST */
 
 static void tls_audit_log_func(gnutls_session_t session, const char *str)
 {
@@ -457,6 +454,7 @@ static void tls_audit_log_func(gnutls_session_t session, const char *str)
 	}
 }
 
+#ifndef UNDER_TEST
 static int verify_certificate_cb(gnutls_session_t session)
 {
 	unsigned int status;
@@ -540,6 +538,7 @@ no_cert:
 fail:
 	return GNUTLS_E_CERTIFICATE_ERROR;
 }
+#endif /* UNDER_TEST */
 
 void tls_global_init(void)
 {
@@ -571,10 +570,9 @@ void tls_vhost_deinit(struct vhost_cfg_st *vhost)
 	vhost->creds.xcred = NULL;
 	vhost->creds.pskcred = NULL;
 	vhost->creds.cprio = NULL;
-
-	return;
 }
 
+#ifndef UNDER_TEST
 /* Checks, if there is a single certificate specified, whether it
  * is compatible with all ciphersuites */
 static void certificate_check(main_server_st *s, const char *vhostname, gnutls_pcert_st *pcert)
@@ -640,7 +638,6 @@ cleanup:
 		gnutls_x509_crt_deinit(crt);
 	gnutls_free(data.data);
 	gnutls_free(dn.data);
-	return;
 }
 
 static void set_dh_params(main_server_st* s, struct vhost_cfg_st *vhost)
@@ -669,7 +666,6 @@ static void set_dh_params(main_server_st* s, struct vhost_cfg_st *vhost)
 	}
 }
 
-#ifndef UNDER_TEST
 struct key_cb_data {
 	unsigned pk;
 	unsigned bits;
@@ -1016,8 +1012,6 @@ void tls_load_files(main_server_st *s, struct vhost_cfg_st *vhost)
 	}
 
 	tls_reload_ocsp(s, vhost);
-
-	return;
 }
 
 static int ocsp_get_func(gnutls_session_t session, void *ptr, gnutls_datum_t *response)
@@ -1071,8 +1065,6 @@ void tls_load_prio(main_server_st *s, struct vhost_cfg_st *vhost)
 	if (ret == GNUTLS_E_PARSING_ERROR)
 		mslog(s, NULL, LOG_ERR, "error in TLS priority string: %s", perr);
 	GNUTLS_FATAL_ERR(ret);
-
-	return;
 }
 
 /*
@@ -1117,7 +1109,7 @@ void tls_reload_crl(main_server_st* s, struct vhost_cfg_st *vhost, unsigned forc
 		mslog(s, NULL, LOG_INFO, "loaded CRL: %s", vhost->perm_config.config->crl);
 	}
 }
-#endif
+#endif /* UNDER_TEST */
 
 void tls_cork(gnutls_session_t session)
 {
@@ -1185,7 +1177,7 @@ void *calc_sha1_hash(void *pool, char* file, unsigned cert)
 
 	/* convert to all caps */
 	for (i=0;i<ret_size;i++)
-	        retval[i] = c_toupper(retval[i]);
+	        retval[i] = toupper(retval[i]);
 
 	return retval;
 }
