@@ -22,8 +22,7 @@
 #include <stdarg.h>
 #include <stdio.h>
 #include <string.h>
-#include <c-strcase.h>
-#include <c-ctype.h>
+#include <ctype.h>
 
 unsigned valid_hostname(const char *host)
 {
@@ -34,8 +33,8 @@ unsigned valid_hostname(const char *host)
 	if (*p == '-')
 		return 0;
 
-	while(*p != 0) {
-		if (!(c_isalnum(*p)) && !(*p == '-'))
+	while (*p != 0) {
+		if (!(isalnum(*p)) && !(*p == '-'))
 			return 0;
 		p++;
 	}
