@@ -31,7 +31,6 @@
 #include <unistd.h>
 #include <net/if.h>
 #include <netinet/in.h>
-#include <minmax.h>
 #include <auth/common.h>
 
 #include <ipc.pb-c.h>
@@ -306,6 +305,7 @@ struct cfg_st {
 	unsigned cisco_client_compat; /* do not require client certificate,
 	                               * and allow auth to complete in different
 	                               * TCP sessions. */
+	unsigned cisco_svc_client_compat; /* force allowed ciphers and disable dtls-legacy */
 	unsigned rate_limit_ms; /* if non zero force a connection every rate_limit milliseconds if ocserv-sm is heavily loaded */
 	unsigned ping_leases; /* non zero if we need to ping prior to leasing */
 	unsigned server_drain_ms; /* how long to wait after we stop accepting new connections before closing old connections */
@@ -358,6 +358,10 @@ struct cfg_st {
 
 	/* holds a usage count of holders of pointers in this struct */
 	int *usage_count;
+
+	bool camouflage;
+	char *camouflage_secret;
+	char *camouflage_realm;
 };
 
 struct perm_cfg_st {
