@@ -109,7 +109,6 @@ static const char ocv3_success_msg_foot[] = "</auth>\n";
 #endif
 
 
-static int get_cert_info(worker_st * ws);
 static int basic_auth_handler(worker_st * ws, unsigned http_ver, const char *msg);
 
 #ifdef SUPPORT_OIDC_AUTH
@@ -618,7 +617,7 @@ unsigned check_if_default_route(char **routes, unsigned routes_size)
 	for (i=0;i<routes_size;i++) {
 		if (strcmp(routes[i], "default") == 0 ||
 		    strcmp(routes[i], "0.0.0.0/0") == 0)
-		    return 1;
+			return 1;
 	}
 
 	return 0;
@@ -770,7 +769,7 @@ int connect_to_secmod(worker_st * ws)
 	return sd;
 }
 
-static int recv_auth_reply(worker_st * ws, int sd, char **txt, unsigned *pcounter)
+int recv_auth_reply(worker_st * ws, int sd, char **txt, unsigned *pcounter)
 {
 	int ret;
 	SecAuthReplyMsg *msg = NULL;
@@ -859,7 +858,6 @@ static int recv_auth_reply(worker_st * ws, int sd, char **txt, unsigned *pcounte
 }
 
 /* grabs the username from the session certificate */
-static
 int get_cert_info(worker_st * ws)
 {
 	const gnutls_datum_t *cert;
@@ -919,6 +917,12 @@ void cookie_authenticate_or_exit(worker_st *ws)
 	ret = auth_cookie(ws, ws->cookie, sizeof(ws->cookie));
 	if (ret < 0) {
 		oclog(ws, LOG_WARNING, "failed cookie authentication attempt");
+		if (WSCONFIG(ws)->camouflage && ws->camouflage_check_passed == 0)
+		{
+			cstp_puts(ws,
+				 "HTTP/1.1 405 Method Not Allowed\r\n\r\n");
+		}
+		else
 		if (ret == ERR_AUTH_FAIL) {
 			cstp_puts(ws,
 				 "HTTP/1.1 401 Cookie is not acceptable\r\n\r\n");
@@ -1242,7 +1246,6 @@ int match_password_in_reply(worker_st * ws, char *body, unsigned body_length,
  * @xml_field: the XML field to check for (e.g., MYFIELD)
  * @value: the value that was found
  */
-static
 int parse_reply(worker_st * ws, char *body, unsigned body_length,
 		const char *field, unsigned field_size,
 		const char *xml_field, unsigned xml_field_size,
