@@ -42,8 +42,7 @@
 #include <gettime.h>
 #include <common.h>
 #include <html.h>
-#include <c-strcase.h>
-#include <c-ctype.h>
+#include <ctype.h>
 #include <worker-bandwidth.h>
 #include <signal.h>
 #include <poll.h>
@@ -166,6 +165,7 @@ inline static ssize_t dtls_pull_buffer_non_empty(gnutls_transport_ptr_t ptr)
 	return 0;
 }
 
+#if !defined(CAPTURE_LATENCY_SUPPORT)
 static
 ssize_t dtls_pull(gnutls_transport_ptr_t ptr, void *data, size_t size)
 {
@@ -184,6 +184,7 @@ ssize_t dtls_pull(gnutls_transport_ptr_t ptr, void *data, size_t size)
 	}
 	return recv(p->fd, data, size, 0);
 }
+#endif
 
 static
 int dtls_pull_timeout(gnutls_transport_ptr_t ptr, unsigned int ms)
@@ -490,8 +491,6 @@ void ws_add_score_to_ip(worker_st *ws, unsigned points, unsigned final, unsigned
 	}
 
 	ban_ip_reply_msg__free_unpacked(reply, &pa);
-
-	return;
 }
 
 void send_stats_to_secmod(worker_st * ws, time_t now, unsigned discon_reason)
@@ -575,38 +574,42 @@ void exit_worker_reason(worker_st * ws, unsigned reason)
 
 #define HANDSHAKE_SESSION_ID_POS (34)
 #define SKIP_V16(pos, total) \
-	{ uint16_t _s; \
-	  if (pos+2 > total) goto finish; \
-	  _s = (msg->data[pos] << 8) | msg->data[pos+1]; \
-	  if (pos+2+_s > total) goto finish; \
-	  pos += 2+_s; \
+	{ \
+		uint16_t _s; \
+		if (pos+2 > total) goto finish; \
+		_s = (msg->data[pos] << 8) | msg->data[pos+1]; \
+		if (pos+2+_s > total) goto finish; \
+		pos += 2+_s; \
 	}
 
-#define SKIP16(pos, total) \
+#define SKIP16(pos, total) { \
 	  if (pos+2 > total) goto finish; \
-	  pos += 2
+	  pos += 2; }
 
-#define SKIP8(pos, total) \
+#define SKIP8(pos, total) { \
 	  if (pos+1 > total) goto finish; \
-	  pos++
+	  pos++; }
 
 #define SKIP_V8(pos, total) \
-	{ uint8_t _s; \
-	  if (pos+1 > total) goto finish; \
-	  _s = msg->data[pos]; \
-	  if (pos+1+_s > total) goto finish; \
-	  pos += 1+_s; \
+	{ \
+		uint8_t _s; \
+		if (pos+1 > total) goto finish; \
+		_s = msg->data[pos]; \
+		if (pos+1+_s > total) goto finish; \
+		pos += 1+_s; \
 	}
 
 #define SET_VHOST_CREDS \
-	ret = \
-	    gnutls_credentials_set(session, GNUTLS_CRD_CERTIFICATE, \
-				   WSCREDS(ws)->xcred); \
-	GNUTLS_FATAL_ERR(ret); \
-	gnutls_certificate_server_set_request(session, WSCONFIG(ws)->cert_req); \
-	ret = gnutls_priority_set(session, WSCREDS(ws)->cprio); \
-	GNUTLS_FATAL_ERR(ret); \
-	gnutls_db_set_cache_expiration(session, TLS_SESSION_EXPIRATION_TIME(WSCONFIG(ws)))
+	do { \
+		ret = \
+		gnutls_credentials_set(session, GNUTLS_CRD_CERTIFICATE, \
+					WSCREDS(ws)->xcred); \
+		GNUTLS_FATAL_ERR(ret); \
+		gnutls_certificate_server_set_request(session, WSCONFIG(ws)->cert_req); \
+		ret = gnutls_priority_set(session, WSCREDS(ws)->cprio); \
+		GNUTLS_FATAL_ERR(ret); \
+		gnutls_db_set_cache_expiration(session, TLS_SESSION_EXPIRATION_TIME(WSCONFIG(ws))); \
+	} while (0)
 
 /* Parse the TLS client hello to figure vhost */
 static int hello_hook_func(gnutls_session_t session, unsigned int htype,
@@ -679,7 +682,7 @@ static int hello_hook_func(gnutls_session_t session, unsigned int htype,
 			      "client requested hostname: %s", (char*)ws->buffer);
 
 			ws->vhost = find_vhost(ws->vconfig, (char*)ws->buffer);
-			if (ws->vhost->name && c_strcasecmp(ws->vhost->name, (char*)ws->buffer) != 0) {
+			if (ws->vhost->name && strcasecmp(ws->vhost->name, (char*)ws->buffer) != 0) {
 				oclog(ws, LOG_INFO,
 				      "client requested hostname %s does not match known vhost", (char*)ws->buffer);
 			}
@@ -733,7 +736,7 @@ static void peek_client_hello(struct worker_st *ws, gnutls_session_t session, in
 			goto fallback;
 
 		hsize = (ws->buffer[3] << 8) | ws->buffer[4];
-	} while(hsize+TLS_RECORD_HEADER > size);
+	} while (hsize+TLS_RECORD_HEADER > size);
 
 	if (size < TLS_RECORD_HEADER+TLS_HANDSHAKE_HEADER+HANDSHAKE_SESSION_ID_POS)
 		goto fallback;
@@ -750,6 +753,20 @@ static void peek_client_hello(struct worker_st *ws, gnutls_session_t session, in
 }
 #endif
 
+void check_camouflage_url(struct worker_st *ws)
+{
+	if (WSCONFIG(ws)->camouflage_secret == NULL)
+		return;
+
+	char* url_camouflage_part = strchr(ws->req.url, '?');
+	if (url_camouflage_part
+		&& !strcmp(url_camouflage_part + 1, WSCONFIG(ws)->camouflage_secret))
+	{
+		*url_camouflage_part = '\0';
+		ws->camouflage_check_passed = 1;
+	}
+}
+
 /* vpn_server:
  * @ws: an initialized worker structure
  *
@@ -921,6 +938,21 @@ void vpn_server(struct worker_st *ws)
 		}
 	} while (ws->req.headers_complete == 0);
 
+	if ((parser.method == HTTP_GET || parser.method == HTTP_POST) &&
+		(WSCONFIG(ws)->camouflage && ws->camouflage_check_passed == 0))
+	{
+		check_camouflage_url(ws);
+		if (ws->camouflage_check_passed == 0)
+		{
+			oclog(ws, LOG_INFO, "Secret not found in URL, declining...");
+			if (WSCONFIG(ws)->camouflage_realm)
+				response_401(ws, parser.http_minor, WSCONFIG(ws)->camouflage_realm);
+			else
+				response_404(ws, parser.http_minor);
+			goto finish;
+		}
+	}
+
 	if (parser.method == HTTP_GET) {
 		oclog(ws, LOG_HTTP_DEBUG, "HTTP GET %s", ws->req.url);
 		fn = http_get_url_handler(ws->req.url);
@@ -1182,14 +1214,13 @@ void mtu_ok(worker_st * ws, struct dtls_st * dtls)
 	c = (ws->link_mtu + ws->last_bad_mtu) / 2;
 
 	link_mtu_set(ws, dtls, c);
-	return;
 }
 
-#define FUZZ(x, diff, rnd) \
-		if (x > diff) { \
-			int16_t r = rnd; \
-			x += r % diff; \
-		}
+#define FUZZ(x, diff, rnd) { \
+	if (x > diff) { \
+		int16_t r = rnd; \
+		x += r % diff; \
+	}}
 
 int get_pmtu_approx(worker_st *ws)
 {
@@ -1349,11 +1380,9 @@ static void set_no_delay(worker_st * ws, int fd)
 	int ret;
 
 	ret = setsockopt(fd, IPPROTO_TCP, TCP_NODELAY, &flag, sizeof(flag));
-	if (ret == -1) {
+	if (ret == -1)
 		oclog(ws, LOG_DEBUG,
 		      "setsockopt(TCP_NODELAY) to %x, failed.", (unsigned)flag);
-		return;
-	}
 }
 
 #define TOSCLASS(x) (IPTOS_CLASS_CS##x)
@@ -1374,7 +1403,7 @@ static void set_net_priority(worker_st * ws, int fd, int priority)
 	}
 #endif
 
-#ifdef SO_PRIORITY
+#if defined(SO_PRIORITY)
 	if (priority != 0 && priority <= 7) {
 		t = ws->user_config->net_priority - 1;
 		ret = setsockopt(fd, SOL_SOCKET, SO_PRIORITY, &t, sizeof(t));
@@ -1385,10 +1414,9 @@ static void set_net_priority(worker_st * ws, int fd, int priority)
 		return;
 	}
 #endif
-	return;
 }
 
-#define SEND_ERR(x) if (x<0) goto send_error
+#define SEND_ERR(x) { if (x<0) goto send_error; }
 
 static int dtls_mainloop(worker_st * ws, struct dtls_st * dtls, struct timespec *tnow)
 {
@@ -2062,16 +2090,16 @@ static int connect_handler(worker_st * ws)
 		oclog(ws, LOG_INFO, "IPv6 routes/DNS disabled because IPv6 support was not requested.");
 	} else {
 		switch (req->user_agent_type) {
-			case AGENT_OPENCONNECT:
-			case AGENT_ANYCONNECT:
-			case AGENT_OPENCONNECT_CLAVISTER:
-			case AGENT_ANYLINK:
-				break;
-			case AGENT_OPENCONNECT_V3:
-			case AGENT_UNKNOWN:
-			default:
-				req->no_ipv6 = 1;
-				oclog(ws, LOG_INFO, "IPv6 routes/DNS disabled because the agent is not known.");
+		case AGENT_OPENCONNECT:
+		case AGENT_ANYCONNECT:
+		case AGENT_OPENCONNECT_CLAVISTER:
+		case AGENT_ANYLINK:
+			break;
+		case AGENT_OPENCONNECT_V3:
+		case AGENT_UNKNOWN:
+		default:
+			req->no_ipv6 = 1;
+			oclog(ws, LOG_INFO, "IPv6 routes/DNS disabled because the agent is not known.");
 		}
 	}
 
