@@ -19,6 +19,7 @@
 #include <config.h>
 
 #include <sys/resource.h>
+#include <locale.h>
 
 #include <system.h>
 #include "setproctitle.h"
@@ -38,7 +39,7 @@
 #ifdef HAVE_GSSAPI
 #include <libtasn1.h>
 
-extern const ASN1_ARRAY_TYPE kkdcp_asn1_tab[];
+extern const asn1_static_node kkdcp_asn1_tab[];
 asn1_node _kkdcp_pkix1_asn = NULL;
 #endif
 
@@ -71,6 +72,12 @@ int main(int argc, char **argv)
 		exit(EXIT_FAILURE);
 	}
 
+	/* ensure our string comparisons do not take into account any system
+	 * locale. We compare strings that come through our configuration or
+	 * network. */
+	setlocale(LC_CTYPE, "C");
+	setlocale(LC_COLLATE, "C");
+
 	/* main pool */
 	main_pool = talloc_init("main");
 	if (main_pool == NULL) {
